@@ -6,38 +6,10 @@ import pydicom
 from phi_finder.dicom_tools import anonymise_dicom
 
 
-def _log_session(data_row: DataRow, key: str, message: str) -> None:
-    """Logs a message to the session's debug-dump field.
-
-    Parameters
-    ----------
-    data_row : DataRow
-        The data row containing the session to log the message to.
-
-    key : str
-        The key of the field to log the message to.
-
-    message : str
-        The message to log.
-
-    Returns
-    -------
-    None : None
-        The function does not return anything.
-    """
-    with data_row.frameset.store.connection:
-        xlogin = data_row.frameset.store.connection.session
-        xproject = xlogin.projects[data_row.frameset.id]
-        xsession = xproject.experiments[data_row.id]
-        xsession.fields[key] = message
-    return None
-
-
 def deidentify_dicom_files(data_row: DataRow,
                            score_threshold: float=0.5,
                            destroy_pixels: bool=True,
-                           use_transformers: bool=False,
-                           dry_run: bool=False) -> None:
+                           use_transformers: bool=False) -> None:
     """Main function to deidentify dicom files in a data row.
         1. Download the files from the original scan entry fmap/DICOM
         2. Anonymise those files and store the anonymised files in a temp dir
@@ -60,45 +32,31 @@ def deidentify_dicom_files(data_row: DataRow,
     use_transformers : bool, optional (default False)
         If True, transformers will be used for anonymisation on top of Presidio's output.
 
-    dry_run : bool, optional (default False)
-        If True, the function will not perform any changes, only log the actions that would be taken.
-        Note that original DICOM files will still be loaded.
-
     Returns
     -------
-    None : None
-        The function does not return anything.
-
+    data_row : None
     """
-    _log_session(data_row, "debug-dump0", "Pipeline started")
-
     entries = list(data_row.entries_dict.items())
-    for resource_path_key_order, entry in entries:
-        resource_path = resource_path_key_order[0]
-        order_key = resource_path_key_order[1]
+    for resource_path, entry in entries:
         # 0. Check if the entry is a DICOM series and not a derivative.
         if entry.datatype != DicomSeries:
             print(f"Skipping {resource_path} as it is not a DICOM series.")
-            _log_session(data_row, "debug-dump1", f"Skipping {resource_path} as it is not a DICOM series.")
             continue
         if entry.is_derivative:
             print(f"Skipping {resource_path} as it is a derivative.")
-            _log_session(data_row, "debug-dump1", f"Skipping {resource_path} as it is a derivative.")
             continue
-        anonymised_resource_path = str(order_key) + '_' + resource_path.replace("/DICOM", "@deidentified")
+        anonymised_resource_path = resource_path.replace("/DICOM", "@deidentified")
+        if anonymised_resource_path in [x[0] for x in entries]:  # x: (name: str, entry: DataEntry)
+            print(f"Skipping {resource_path} as it is already anonymised.")
+            continue
 
         print(f"De-identifying {resource_path} to {anonymised_resource_path}.")
-        _log_session(data_row, "debug-dump2", f"De-identifying {resource_path} to {anonymised_resource_path}.")
-
         # 1. Downloading the files from the original scan entry.
         dicom_series = entry.item
-        _log_session(data_row, "debug-dump3", f"Files from the original scan entry were downloaded.")
 
         # 2. Anonymising those files.
         tmps_paths = []
         for i, dicom in enumerate(dicom_series.contents):
-            if dry_run:
-                continue
             dcm = pydicom.dcmread(dicom)
             anonymised_dcm = anonymise_dicom.anonymise_image(dcm,
                                                              score_threshold=score_threshold,
@@ -109,35 +67,16 @@ def deidentify_dicom_files(data_row: DataRow,
             anonymised_dcm.save_as(tmp_path)
             tmps_paths.append(tmp_path)
 
-        if dry_run:
-            _log_session(data_row, "debug-dump4", f"Files anonymised (dry-run).")
-        else:
-            _log_session(data_row, "debug-dump4", f"Files anonymised.")
-
-        # 3. Creating the deidentified entry if necessary.
-        entries_names = [x[0][0] for x in entries]  # x: ((name: str, order_key: str), entry: DataEntry)
-        if dry_run:
-            _log_session(data_row, "debug-dump6", f"Deidentified files uploaded (dry-run).")
-            return
-
-        if anonymised_resource_path in entries_names:
-            print(f"Re-using {anonymised_resource_path} that already exists.")
-            _log_session(data_row, "debug-dump5", f"Re-using {anonymised_resource_path} that already exists.")
-            index = entries_names.index(anonymised_resource_path)
-            anonymised_session_entry = entries[index][1]
-        else:
-            anonymised_session_entry = data_row.create_entry(
-                anonymised_resource_path, datatype=DicomSeries, order_key=order_key
-            )
-            _log_session(data_row, "debug-dump5", f"Deidentified entry created.")
+        # 3. Creating the deidentified entry.
+        anonymised_session_entry = data_row.create_entry(
+            anonymised_resource_path, datatype=DicomSeries
+        )
 
         # 4. Creating a new DicomSeries object from the anonymised files.
         anonymised_dcm_series = DicomSeries(tmps_paths)
 
         # 5. Uploading the anonymised files from the temp dir.
         anonymised_session_entry.item = anonymised_dcm_series
-        _log_session(data_row, "debug-dump6", f"Deidentified files uploaded.")
-
     return None
 
 
@@ -166,7 +105,6 @@ def _get_dicom_files(data_row: DataRow) -> list:
         return pixel_arrays
 
     resource_paths = list(data_row.entries_dict.keys())
-    resource_paths = [x[0] if isinstance(x, tuple) else x for x in resource_paths]
     dicom_files = []
     for resource_path in resource_paths:
         dicom_files.extend(_get_dicom_in_session(resource_path))
@@ -213,11 +151,42 @@ def _count_dicom_files(data_row: DataRow, resource_path: str | None = None) -> i
     if not resource_path:
         session_keys = list(
             data_row.entries_dict.keys()
-        )  # Copy, not reference, of the keys, e.g. [('fmap/DICOM', '1'), ('t1w/DICOM', '1'), ('dwi/DICOM', '1')]
+        )  # Copy, not reference, of the keys, e.g. ['fmap/DICOM', 't1w/DICOM', 'dwi/DICOM']
         n_scans = 0
-        session_keys = [x[0] if isinstance(x, tuple) else x for x in session_keys]
         for resource_path in session_keys:
             n_scans += _count_dicom_in_session(resource_path)
         return n_scans
     else:
         return _count_dicom_in_session(resource_path)
+
+
+def compare_dicom_files_headers(original: pydicom.dataset.FileDataset,
+                                anonymised: pydicom.dataset.FileDataset) -> bool:
+    """Compares the metadata of two DICOM files to check if they are identical.
+
+    Parameters
+    ----------
+    original : pydicom.dataset.FileDataset
+        The original DICOM dataset.
+
+    anonymised : pydicom.dataset.FileDataset
+        The anonymised DICOM dataset.
+
+    Returns
+    -------
+    bool
+        True if the pixel data is identical, False otherwise.
+    """
+    c = 0
+    total = 0
+    for element in original.elements():
+        elem_original = original[element.tag]
+        original_value = elem_original.value
+
+        elem_anonymised = anonymised[element.tag]
+        anonymised_value = elem_anonymised.value
+
+        if original_value != anonymised_value:
+            c+=1
+        total += 1
+    return c, total
